@@ -3,16 +3,16 @@ use utf8;
 use strict;
 use warnings FATAL => 'all';
 
-use Muldis::Rosetta::Interface 0.012000;
+use Muldis::Rosetta::Interface 0.013000;
 
 ###########################################################################
 ###########################################################################
 
 { package Muldis::Rosetta::Validator; # module
-    use version 0.74; our $VERSION = qv('0.12.0');
+    use version 0.74; our $VERSION = qv('0.13.0');
 
     use Test::More;
-    use Test::Moose 0.57;
+    use Test::Moose 0.61;
 
 ###########################################################################
 
@@ -36,7 +36,7 @@ sub main {
     });
     does_ok( $process, 'Muldis::Rosetta::Interface::Process' );
     $process->update_hd_command_lang({ 'lang' => [ 'Muldis_D',
-        'http://muldis.com', '0.48.0', 'HDMD_Perl_Tiny', {} ] });
+        'http://muldis.com', '0.50.0', 'HDMD_Perl_Tiny', {} ] });
 
     _scenario_foods_suppliers_shipments_v1( $process );
 
@@ -54,22 +54,22 @@ sub _scenario_foods_suppliers_shipments_v1 {
     # Declare our example literal source data sets.
 
     my $src_suppliers = $process->new_value({
-        'source_code' => [ 'Relation', [ 'farm', 'country', ], [
-            [ [ 'Text', 'Hodgesons' ], [ 'Text', 'Canada'  ], ],
-            [ [ 'Text', 'Beckers'   ], [ 'Text', 'England' ], ],
-            [ [ 'Text', 'Wickets'   ], [ 'Text', 'Canada'  ], ],
+        'source_code' => [ 'Relation', [ 'farm', 'country' ], [
+            [ [ 'Text', 'Hodgesons' ], [ 'Text', 'Canada'  ] ],
+            [ [ 'Text', 'Beckers'   ], [ 'Text', 'England' ] ],
+            [ [ 'Text', 'Wickets'   ], [ 'Text', 'Canada'  ] ],
         ] ],
     });
     pass( 'no death from loading example suppliers data into VM' );
     does_ok( $src_suppliers, 'Muldis::Rosetta::Interface::Value' );
 
     my $src_foods = $process->new_value({
-        'source_code' => [ 'Relation', [ 'food', 'colour', ], [
-            [ [ 'Text', 'Bananas' ], [ 'Text', 'yellow' ], ],
-            [ [ 'Text', 'Carrots' ], [ 'Text', 'orange' ], ],
-            [ [ 'Text', 'Oranges' ], [ 'Text', 'orange' ], ],
-            [ [ 'Text', 'Kiwis'   ], [ 'Text', 'green'  ], ],
-            [ [ 'Text', 'Lemons'  ], [ 'Text', 'yellow' ], ],
+        'source_code' => [ 'Relation', [ 'food', 'colour' ], [
+            [ [ 'Text', 'Bananas' ], [ 'Text', 'yellow' ] ],
+            [ [ 'Text', 'Carrots' ], [ 'Text', 'orange' ] ],
+            [ [ 'Text', 'Oranges' ], [ 'Text', 'orange' ] ],
+            [ [ 'Text', 'Kiwis'   ], [ 'Text', 'green'  ] ],
+            [ [ 'Text', 'Lemons'  ], [ 'Text', 'yellow' ] ],
         ] ],
     });
     pass( 'no death from loading example foods data into VM' );
@@ -80,37 +80,37 @@ sub _scenario_foods_suppliers_shipments_v1 {
             {
                 'farm' => [ 'Text', 'Hodgesons' ],
                 'food' => [ 'Text', 'Kiwis' ],
-                'qty'  => [ 'Int', 'perl_int', 100 ],
+                'qty'  => [ 'Int', 100 ],
             },
             {
                 'farm' => [ 'Text', 'Hodgesons' ],
                 'food' => [ 'Text', 'Lemons' ],
-                'qty'  => [ 'Int', 'perl_int', 130 ],
+                'qty'  => [ 'Int', 130 ],
             },
             {
                 'farm' => [ 'Text', 'Hodgesons' ],
                 'food' => [ 'Text', 'Oranges' ],
-                'qty'  => [ 'Int', 'perl_int', 10 ],
+                'qty'  => [ 'Int', 10 ],
             },
             {
                 'farm' => [ 'Text', 'Hodgesons' ],
                 'food' => [ 'Text', 'Carrots' ],
-                'qty'  => [ 'Int', 'perl_int', 50 ],
+                'qty'  => [ 'Int', 50 ],
             },
             {
                 'farm' => [ 'Text', 'Beckers' ],
                 'food' => [ 'Text', 'Carrots' ],
-                'qty'  => [ 'Int', 'perl_int', 90 ],
+                'qty'  => [ 'Int', 90 ],
             },
             {
                 'farm' => [ 'Text', 'Beckers' ],
                 'food' => [ 'Text', 'Bananas' ],
-                'qty'  => [ 'Int', 'perl_int', 120 ],
+                'qty'  => [ 'Int', 120 ],
             },
             {
                 'farm' => [ 'Text', 'Wickets' ],
                 'food' => [ 'Text', 'Lemons' ],
-                'qty'  => [ 'Int', 'perl_int', 30 ],
+                'qty'  => [ 'Int', 30 ],
             },
         ] ],
     });
@@ -149,9 +149,9 @@ sub _scenario_foods_suppliers_shipments_v1 {
 
     # Finally, use the result somehow (not done here).
     # The result should be:
-    # [ 'Relation', [ 'farm', 'country', ], [
-    #     [ [ 'Text', 'Hodgesons' ], [ 'Text', 'Canada'  ], ],
-    #     [ [ 'Text', 'Beckers'   ], [ 'Text', 'England' ], ],
+    # [ 'Relation', [ 'farm', 'country' ], [
+    #     [ [ 'Text', 'Hodgesons' ], [ 'Text', 'Canada'  ] ],
+    #     [ [ 'Text', 'Beckers'   ], [ 'Text', 'England' ] ],
     # ] ],
 
     print "# debug: orange food suppliers found:\n";
@@ -182,7 +182,7 @@ A common comprehensive test suite to run against all Engines
 
 =head1 VERSION
 
-This document describes Muldis::Rosetta::Validator version 0.12.0 for Perl
+This document describes Muldis::Rosetta::Validator version 0.13.0 for Perl
 5.
 
 =head1 SYNOPSIS
@@ -267,13 +267,14 @@ recommends one that is at least 5.10.0.
 
 It also requires these Perl 5 packages that are bundled with any version of
 Perl 5.x.y that is at least 5.10.0, and are also on CPAN for separate
-installation by users of earlier Perl versions: L<version-0.74|version>.
+installation by users of earlier Perl versions:
+L<version:ver(0.74..*)|version>.
 
 It also requires these Perl 5 packages that are on CPAN:
-L<Test::Moose-0.57|Test::Moose>.
+L<Test::Moose:ver(0.61..*)|Test::Moose>.
 
 It also requires these Perl 5 classes that are in the current distribution:
-L<Muldis::Rosetta::Interface-0.12.0|Muldis::Rosetta::Interface>.
+L<Muldis::Rosetta::Interface:ver(0.13.0..*)|Muldis::Rosetta::Interface>.
 
 =head1 INCOMPATIBILITIES
 
